X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/d17b1e7621c1b1ed92f1fa321112757a2a8cc367..3bc2d7aeda2999126184c298f26b93ffd59be500:/include/wx/debug.h

diff --git a/include/wx/debug.h b/include/wx/debug.h
index 50d938e1a9..06f302d820 100644
--- a/include/wx/debug.h
+++ b/include/wx/debug.h
@@ -47,13 +47,23 @@
     #endif /*  !WXDEBUG */
 #endif /*  __WXDEBUG__ */
 
-/* TODO: add more compilers supporting __FUNCTION__ */
-#if !defined(__GNUC__) && \
-    !(defined(_MSC_VER) && _MSC_VER >= 1300) && \
-    !defined(__FUNCTION__)
-    /* no __FUNCTION__ support, still define it to avoid #ifdefs elsewhere */
-    #define __FUNCTION__ (NULL)
-#endif
+#ifndef __WXFUNCTION__
+    /* TODO: add more compilers supporting __FUNCTION__ */
+    #if defined(__DMC__)
+        /* 
+           __FUNCTION__ happens to be not defined within class members
+           http://www.digitalmars.com/drn-bin/wwwnews?c%2B%2B.beta/485
+        */
+        #define __WXFUNCTION__ (NULL)
+    #elif defined(__GNUC__) || \
+          (defined(_MSC_VER) && _MSC_VER >= 1300) || \
+          defined(__FUNCTION__)
+        #define __WXFUNCTION__ __FUNCTION__
+    #else
+        /* still define __WXFUNCTION__ to avoid #ifdefs elsewhere */
+        #define __WXFUNCTION__ (NULL)
+    #endif
+#endif /* __WXFUNCTION__ already defined */
 
 /*  ---------------------------------------------------------------------------- */
 /*  Debugging macros */
@@ -108,7 +118,7 @@
     if ( cond )                                                               \
         ;                                                                     \
     else                                                                      \
-        wxOnAssert(__TFILE__, __LINE__, __FUNCTION__, _T(#cond), msg)
+        wxOnAssert(__TFILE__, __LINE__, __WXFUNCTION__, _T(#cond), msg)
 
   /*  special form of assert: always triggers it (in debug mode) */
   #define wxFAIL wxFAIL_MSG(NULL)
@@ -118,7 +128,7 @@
 
   /*  FAIL with some message and a condition */
   #define wxFAIL_COND_MSG(cond, msg)                                          \
-      wxOnAssert(__TFILE__, __LINE__,  __FUNCTION__, _T(cond), msg)
+      wxOnAssert(__TFILE__, __LINE__,  __WXFUNCTION__, _T(cond), msg)
 
   /*  an assert helper used to avoid warning when testing constant expressions, */
   /*  i.e. wxASSERT( sizeof(int) == 4 ) can generate a compiler warning about */